@@ -77,6 +77,12 @@ SENTENCES = [
         ("イタㇰ", "Itak"),
         # Whatever this is
         ("エィッリィククワッドゥロッウ", "Irrikukuwadduro-u"),
+        # small か
+        ("夕陽ヵ丘三号館", "Yuuhi kakyuu san goukan"),
+        # deal with combining dakuten
+        ("青い春よさらば！", "Aoi haru yo saraba!"),
+        # small ケ
+        ("齋藤タヶオ", "Saitou ta ke o")
         ]
 
 SENTENCES_KUNREI = [
